// generated from rosidl_generator_c/resource/idl__description.c.em
// with input from tf2_msgs:action/LookupTransform.idl
// generated code does not contain a copyright notice

#include "tf2_msgs/action/detail/lookup_transform__functions.h"

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform__get_type_hash(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x0b, 0x8a, 0xdf, 0x6b, 0xc0, 0xb5, 0x95, 0x88,
      0x79, 0xe3, 0x26, 0x5b, 0x41, 0xa4, 0x57, 0xe0,
      0x35, 0x58, 0xfe, 0x52, 0x38, 0x90, 0xa8, 0x12,
      0x52, 0xc7, 0x0e, 0xba, 0x97, 0xa8, 0x2c, 0x5d,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_Goal__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x81, 0x5e, 0xfc, 0x29, 0x4a, 0xd1, 0x7c, 0x81,
      0x3c, 0x60, 0x43, 0xcd, 0xde, 0x78, 0x1f, 0xf5,
      0x58, 0x10, 0xd4, 0x9d, 0xa0, 0x2e, 0xd0, 0x7f,
      0x92, 0x37, 0xdc, 0xd2, 0x0e, 0x88, 0xd4, 0x98,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_Result__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x06, 0x1d, 0x44, 0x23, 0xaf, 0x53, 0x52, 0xff,
      0x53, 0x14, 0xc8, 0xef, 0xfe, 0xf8, 0xfa, 0xab,
      0x13, 0x39, 0x91, 0xa7, 0x8f, 0x1b, 0x2b, 0xcd,
      0x1f, 0xec, 0xab, 0xad, 0x80, 0x87, 0x12, 0x25,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_Feedback__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x2d, 0xa0, 0xb0, 0x2f, 0x99, 0x0f, 0x04, 0x40,
      0x4a, 0xb8, 0xc9, 0x8a, 0x2a, 0x68, 0xcf, 0x5b,
      0xbc, 0x77, 0x3a, 0xe7, 0x47, 0xf9, 0x69, 0x11,
      0xf2, 0xd5, 0x54, 0x99, 0xcf, 0xb5, 0x15, 0x42,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_SendGoal__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x46, 0x46, 0xff, 0x57, 0x06, 0xc8, 0x6b, 0x04,
      0xd0, 0xa1, 0x09, 0x8d, 0x32, 0x99, 0x51, 0xa9,
      0x73, 0x1a, 0x75, 0x17, 0xe1, 0x67, 0x02, 0x90,
      0x5d, 0xe6, 0x07, 0x3c, 0xc7, 0x2c, 0x85, 0x30,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xeb, 0x13, 0x12, 0xeb, 0x7a, 0xab, 0x35, 0xe3,
      0x5c, 0x71, 0xbb, 0x87, 0xc2, 0xba, 0x3a, 0x94,
      0x74, 0x7c, 0x5a, 0x65, 0x44, 0xea, 0x32, 0xbb,
      0x2b, 0x32, 0xb0, 0xf7, 0x57, 0x75, 0xb8, 0xca,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xc1, 0xad, 0xa9, 0x33, 0x04, 0x79, 0x3c, 0x08,
      0x81, 0x36, 0x57, 0x25, 0x5e, 0x7b, 0xde, 0x2e,
      0x40, 0xe2, 0x11, 0x4a, 0xa6, 0x34, 0xb7, 0x02,
      0xc3, 0xf8, 0xd4, 0xb7, 0x2a, 0xe0, 0x98, 0xbc,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_SendGoal_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x5a, 0xb9, 0x3d, 0x3d, 0x6c, 0x35, 0xb5, 0x63,
      0x90, 0x32, 0x50, 0x99, 0xcb, 0x08, 0x8c, 0x73,
      0xba, 0xe1, 0x76, 0xa3, 0x91, 0x23, 0xf2, 0xf6,
      0xdf, 0xe1, 0x19, 0x58, 0x24, 0x36, 0xac, 0xc5,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_GetResult__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x3c, 0xd1, 0x71, 0x57, 0x51, 0x89, 0x9e, 0x31,
      0x67, 0xb5, 0xae, 0xc3, 0xe4, 0xac, 0x19, 0x4f,
      0x7d, 0xa9, 0xe8, 0x49, 0x3a, 0x77, 0x28, 0x5f,
      0x9f, 0x6a, 0x4c, 0x91, 0x4f, 0x5e, 0x8b, 0x24,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_GetResult_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x14, 0x8f, 0x9b, 0xdc, 0x01, 0xf9, 0x89, 0x22,
      0xd6, 0xfb, 0x20, 0x72, 0xcb, 0x64, 0x46, 0x8b,
      0x89, 0xc5, 0x7c, 0x78, 0x25, 0xd9, 0xd8, 0x3b,
      0x93, 0x2c, 0x18, 0x3d, 0xea, 0xa4, 0x69, 0x7d,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_GetResult_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x95, 0x4d, 0xe3, 0xef, 0xc3, 0x6b, 0x16, 0x4c,
      0x4d, 0x21, 0x11, 0x6a, 0xbd, 0xbd, 0xcc, 0x52,
      0x74, 0x6e, 0x45, 0x4f, 0xd9, 0xc1, 0x69, 0xb5,
      0x5d, 0x9c, 0xfd, 0x89, 0xe8, 0x3d, 0x29, 0x9d,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_GetResult_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x32, 0x60, 0x11, 0x5e, 0x0f, 0x6a, 0x67, 0x6d,
      0x62, 0x1f, 0x19, 0x1f, 0x85, 0xa7, 0x2a, 0x0c,
      0x82, 0xf9, 0xfc, 0xb1, 0x48, 0x39, 0x65, 0xc1,
      0xfb, 0xaa, 0xab, 0x0b, 0x1d, 0x65, 0x1a, 0x9e,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_type_hash_t *
tf2_msgs__action__LookupTransform_FeedbackMessage__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x10, 0xcb, 0x89, 0x92, 0x2d, 0xcb, 0x10, 0x3e,
      0x95, 0xc1, 0x85, 0xd4, 0x3e, 0x8a, 0x5e, 0xfa,
      0x3d, 0x38, 0xdb, 0x99, 0x6f, 0x73, 0x31, 0x51,
      0xa2, 0xf3, 0xe2, 0xac, 0x13, 0x3f, 0x48, 0x39,
    }};
  return &hash;
}

#include <assert.h>
#include <string.h>

// Include directives for referenced types
#include "service_msgs/msg/detail/service_event_info__functions.h"
#include "unique_identifier_msgs/msg/detail/uuid__functions.h"
#include "builtin_interfaces/msg/detail/duration__functions.h"
#include "geometry_msgs/msg/detail/vector3__functions.h"
#include "tf2_msgs/msg/detail/tf2_error__functions.h"
#include "geometry_msgs/msg/detail/transform_stamped__functions.h"
#include "std_msgs/msg/detail/header__functions.h"
#include "builtin_interfaces/msg/detail/time__functions.h"
#include "geometry_msgs/msg/detail/quaternion__functions.h"
#include "geometry_msgs/msg/detail/transform__functions.h"

// Hashes for external referenced types
#ifndef NDEBUG
static const rosidl_type_hash_t builtin_interfaces__msg__Duration__EXPECTED_HASH = {1, {
    0xe8, 0xd0, 0x09, 0xf6, 0x59, 0x81, 0x6f, 0x75,
    0x8b, 0x75, 0x33, 0x4e, 0xe1, 0xa9, 0xca, 0x5b,
    0x5c, 0x0b, 0x85, 0x98, 0x43, 0x26, 0x1f, 0x14,
    0xc7, 0xf9, 0x37, 0x34, 0x95, 0x99, 0xd9, 0x3b,
  }};
static const rosidl_type_hash_t builtin_interfaces__msg__Time__EXPECTED_HASH = {1, {
    0xb1, 0x06, 0x23, 0x5e, 0x25, 0xa4, 0xc5, 0xed,
    0x35, 0x09, 0x8a, 0xa0, 0xa6, 0x1a, 0x3e, 0xe9,
    0xc9, 0xb1, 0x8d, 0x19, 0x7f, 0x39, 0x8b, 0x0e,
    0x42, 0x06, 0xce, 0xa9, 0xac, 0xf9, 0xc1, 0x97,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Quaternion__EXPECTED_HASH = {1, {
    0x8a, 0x76, 0x5f, 0x66, 0x77, 0x8c, 0x8f, 0xf7,
    0xc8, 0xab, 0x94, 0xaf, 0xcc, 0x59, 0x0a, 0x2e,
    0xd5, 0x32, 0x5a, 0x1d, 0x9a, 0x07, 0x6f, 0xff,
    0xf3, 0x8f, 0xbc, 0xe3, 0x6f, 0x45, 0x86, 0x84,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Transform__EXPECTED_HASH = {1, {
    0xbe, 0xb8, 0x3f, 0xbe, 0x69, 0x86, 0x36, 0x35,
    0x14, 0x61, 0xf6, 0xf3, 0x5d, 0x1a, 0xbb, 0x20,
    0x01, 0x0c, 0x43, 0xd5, 0x53, 0x74, 0xd8, 0x1b,
    0xd0, 0x41, 0xf1, 0xba, 0x25, 0x81, 0xfd, 0xdc,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__TransformStamped__EXPECTED_HASH = {1, {
    0x0a, 0x24, 0x1f, 0x87, 0xd0, 0x46, 0x68, 0xd9,
    0x40, 0x99, 0xcb, 0xb5, 0xba, 0x11, 0x69, 0x1d,
    0x5a, 0xd3, 0x2c, 0x2f, 0x29, 0x68, 0x2e, 0x4e,
    0xb5, 0x65, 0x34, 0x24, 0xbd, 0x27, 0x52, 0x06,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Vector3__EXPECTED_HASH = {1, {
    0xcc, 0x12, 0xfe, 0x83, 0xe4, 0xc0, 0x27, 0x19,
    0xf1, 0xce, 0x80, 0x70, 0xbf, 0xd1, 0x4a, 0xec,
    0xd4, 0x0f, 0x75, 0xa9, 0x66, 0x96, 0xa6, 0x7a,
    0x2a, 0x1f, 0x37, 0xf7, 0xdb, 0xb0, 0x76, 0x5d,
  }};
static const rosidl_type_hash_t service_msgs__msg__ServiceEventInfo__EXPECTED_HASH = {1, {
    0x41, 0xbc, 0xbb, 0xe0, 0x7a, 0x75, 0xc9, 0xb5,
    0x2b, 0xc9, 0x6b, 0xfd, 0x5c, 0x24, 0xd7, 0xf0,
    0xfc, 0x0a, 0x08, 0xc0, 0xcb, 0x79, 0x21, 0xb3,
    0x37, 0x3c, 0x57, 0x32, 0x34, 0x5a, 0x6f, 0x45,
  }};
static const rosidl_type_hash_t std_msgs__msg__Header__EXPECTED_HASH = {1, {
    0xf4, 0x9f, 0xb3, 0xae, 0x2c, 0xf0, 0x70, 0xf7,
    0x93, 0x64, 0x5f, 0xf7, 0x49, 0x68, 0x3a, 0xc6,
    0xb0, 0x62, 0x03, 0xe4, 0x1c, 0x89, 0x1e, 0x17,
    0x70, 0x1b, 0x1c, 0xb5, 0x97, 0xce, 0x6a, 0x01,
  }};
static const rosidl_type_hash_t tf2_msgs__msg__TF2Error__EXPECTED_HASH = {1, {
    0xdb, 0x24, 0x85, 0xe7, 0xd6, 0xa0, 0xec, 0x75,
    0xbf, 0x08, 0x7e, 0x05, 0x8e, 0xe4, 0x5d, 0xf6,
    0x82, 0xac, 0xc3, 0xa6, 0x21, 0xca, 0x77, 0x80,
    0x50, 0x3d, 0x10, 0xaa, 0xc1, 0x41, 0x80, 0x9a,
  }};
static const rosidl_type_hash_t unique_identifier_msgs__msg__UUID__EXPECTED_HASH = {1, {
    0x1b, 0x8e, 0x8a, 0xca, 0x95, 0x8c, 0xbe, 0xa2,
    0x8f, 0xe6, 0xef, 0x60, 0xbf, 0x6c, 0x19, 0xb6,
    0x83, 0xc9, 0x7a, 0x9e, 0xf6, 0x0b, 0xb3, 0x47,
    0x52, 0x06, 0x7d, 0x0f, 0x2f, 0x7a, 0xb4, 0x37,
  }};
#endif

static char tf2_msgs__action__LookupTransform__TYPE_NAME[] = "tf2_msgs/action/LookupTransform";
static char builtin_interfaces__msg__Duration__TYPE_NAME[] = "builtin_interfaces/msg/Duration";
static char builtin_interfaces__msg__Time__TYPE_NAME[] = "builtin_interfaces/msg/Time";
static char geometry_msgs__msg__Quaternion__TYPE_NAME[] = "geometry_msgs/msg/Quaternion";
static char geometry_msgs__msg__Transform__TYPE_NAME[] = "geometry_msgs/msg/Transform";
static char geometry_msgs__msg__TransformStamped__TYPE_NAME[] = "geometry_msgs/msg/TransformStamped";
static char geometry_msgs__msg__Vector3__TYPE_NAME[] = "geometry_msgs/msg/Vector3";
static char service_msgs__msg__ServiceEventInfo__TYPE_NAME[] = "service_msgs/msg/ServiceEventInfo";
static char std_msgs__msg__Header__TYPE_NAME[] = "std_msgs/msg/Header";
static char tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_Feedback";
static char tf2_msgs__action__LookupTransform_FeedbackMessage__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_FeedbackMessage";
static char tf2_msgs__action__LookupTransform_GetResult__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_GetResult";
static char tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_GetResult_Event";
static char tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_GetResult_Request";
static char tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_GetResult_Response";
static char tf2_msgs__action__LookupTransform_Goal__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_Goal";
static char tf2_msgs__action__LookupTransform_Result__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_Result";
static char tf2_msgs__action__LookupTransform_SendGoal__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_SendGoal";
static char tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_SendGoal_Event";
static char tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_SendGoal_Request";
static char tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME[] = "tf2_msgs/action/LookupTransform_SendGoal_Response";
static char tf2_msgs__msg__TF2Error__TYPE_NAME[] = "tf2_msgs/msg/TF2Error";
static char unique_identifier_msgs__msg__UUID__TYPE_NAME[] = "unique_identifier_msgs/msg/UUID";

// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform__FIELD_NAME__goal[] = "goal";
static char tf2_msgs__action__LookupTransform__FIELD_NAME__result[] = "result";
static char tf2_msgs__action__LookupTransform__FIELD_NAME__feedback[] = "feedback";
static char tf2_msgs__action__LookupTransform__FIELD_NAME__send_goal_service[] = "send_goal_service";
static char tf2_msgs__action__LookupTransform__FIELD_NAME__get_result_service[] = "get_result_service";
static char tf2_msgs__action__LookupTransform__FIELD_NAME__feedback_message[] = "feedback_message";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__send_goal_service, 17, 17},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__get_result_service, 18, 18},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_GetResult__TYPE_NAME, 41, 41},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform__FIELD_NAME__feedback_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_FeedbackMessage__TYPE_NAME, 47, 47},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Transform__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Vector3__TYPE_NAME, 25, 25},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_FeedbackMessage__TYPE_NAME, 47, 47},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult__TYPE_NAME, 41, 41},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME, 47, 47},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform__get_type_description(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform__TYPE_NAME, 31, 31},
      {tf2_msgs__action__LookupTransform__FIELDS, 6, 6},
    },
    {tf2_msgs__action__LookupTransform__REFERENCED_TYPE_DESCRIPTIONS, 22, 22},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Transform__EXPECTED_HASH, geometry_msgs__msg__Transform__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = geometry_msgs__msg__Transform__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__TransformStamped__EXPECTED_HASH, geometry_msgs__msg__TransformStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__TransformStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Vector3__EXPECTED_HASH, geometry_msgs__msg__Vector3__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = geometry_msgs__msg__Vector3__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = tf2_msgs__action__LookupTransform_Feedback__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = tf2_msgs__action__LookupTransform_FeedbackMessage__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[10].fields = tf2_msgs__action__LookupTransform_GetResult__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[11].fields = tf2_msgs__action__LookupTransform_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[12].fields = tf2_msgs__action__LookupTransform_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[13].fields = tf2_msgs__action__LookupTransform_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[14].fields = tf2_msgs__action__LookupTransform_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[15].fields = tf2_msgs__action__LookupTransform_Result__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[16].fields = tf2_msgs__action__LookupTransform_SendGoal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[17].fields = tf2_msgs__action__LookupTransform_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[18].fields = tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[19].fields = tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&tf2_msgs__msg__TF2Error__EXPECTED_HASH, tf2_msgs__msg__TF2Error__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[20].fields = tf2_msgs__msg__TF2Error__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[21].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__target_frame[] = "target_frame";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__source_frame[] = "source_frame";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__source_time[] = "source_time";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__timeout[] = "timeout";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__target_time[] = "target_time";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__fixed_frame[] = "fixed_frame";
static char tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__advanced[] = "advanced";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_Goal__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__target_frame, 12, 12},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_STRING,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__source_frame, 12, 12},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_STRING,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__source_time, 11, 11},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__timeout, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__target_time, 11, 11},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__fixed_frame, 11, 11},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_STRING,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__FIELD_NAME__advanced, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_BOOLEAN,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_Goal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_Goal__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
      {tf2_msgs__action__LookupTransform_Goal__FIELDS, 7, 7},
    },
    {tf2_msgs__action__LookupTransform_Goal__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_Result__FIELD_NAME__transform[] = "transform";
static char tf2_msgs__action__LookupTransform_Result__FIELD_NAME__error[] = "error";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_Result__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_Result__FIELD_NAME__transform, 9, 9},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Result__FIELD_NAME__error, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_Result__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Transform__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Vector3__TYPE_NAME, 25, 25},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_Result__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
      {tf2_msgs__action__LookupTransform_Result__FIELDS, 2, 2},
    },
    {tf2_msgs__action__LookupTransform_Result__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Transform__EXPECTED_HASH, geometry_msgs__msg__Transform__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = geometry_msgs__msg__Transform__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__TransformStamped__EXPECTED_HASH, geometry_msgs__msg__TransformStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = geometry_msgs__msg__TransformStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Vector3__EXPECTED_HASH, geometry_msgs__msg__Vector3__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__Vector3__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&tf2_msgs__msg__TF2Error__EXPECTED_HASH, tf2_msgs__msg__TF2Error__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = tf2_msgs__msg__TF2Error__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_Feedback__FIELD_NAME__structure_needs_at_least_one_member[] = "structure_needs_at_least_one_member";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_Feedback__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_Feedback__FIELD_NAME__structure_needs_at_least_one_member, 35, 35},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_UINT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_Feedback__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
      {tf2_msgs__action__LookupTransform_Feedback__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__request_message[] = "request_message";
static char tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__response_message[] = "response_message";
static char tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_SendGoal__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME, 46, 46},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_SendGoal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_SendGoal__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_SendGoal__TYPE_NAME, 40, 40},
      {tf2_msgs__action__LookupTransform_SendGoal__FIELDS, 3, 3},
    },
    {tf2_msgs__action__LookupTransform_SendGoal__REFERENCED_TYPE_DESCRIPTIONS, 8, 8},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = tf2_msgs__action__LookupTransform_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = tf2_msgs__action__LookupTransform_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[6].fields = tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_SendGoal_Request__FIELD_NAME__goal_id[] = "goal_id";
static char tf2_msgs__action__LookupTransform_SendGoal_Request__FIELD_NAME__goal[] = "goal";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_SendGoal_Request__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
      {tf2_msgs__action__LookupTransform_SendGoal_Request__FIELDS, 2, 2},
    },
    {tf2_msgs__action__LookupTransform_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS, 4, 4},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = tf2_msgs__action__LookupTransform_Goal__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_SendGoal_Response__FIELD_NAME__accepted[] = "accepted";
static char tf2_msgs__action__LookupTransform_SendGoal_Response__FIELD_NAME__stamp[] = "stamp";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_SendGoal_Response__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__FIELD_NAME__accepted, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_BOOLEAN,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__FIELD_NAME__stamp, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
      {tf2_msgs__action__LookupTransform_SendGoal_Response__FIELDS, 2, 2},
    },
    {tf2_msgs__action__LookupTransform_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__info[] = "info";
static char tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__request[] = "request";
static char tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_SendGoal_Event__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_SendGoal_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME, 46, 46},
      {tf2_msgs__action__LookupTransform_SendGoal_Event__FIELDS, 3, 3},
    },
    {tf2_msgs__action__LookupTransform_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = tf2_msgs__action__LookupTransform_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__request_message[] = "request_message";
static char tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__response_message[] = "response_message";
static char tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_GetResult__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME, 47, 47},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_GetResult__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Transform__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Vector3__TYPE_NAME, 25, 25},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME, 47, 47},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_GetResult__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_GetResult__TYPE_NAME, 41, 41},
      {tf2_msgs__action__LookupTransform_GetResult__FIELDS, 3, 3},
    },
    {tf2_msgs__action__LookupTransform_GetResult__REFERENCED_TYPE_DESCRIPTIONS, 13, 13},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Transform__EXPECTED_HASH, geometry_msgs__msg__Transform__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = geometry_msgs__msg__Transform__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__TransformStamped__EXPECTED_HASH, geometry_msgs__msg__TransformStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = geometry_msgs__msg__TransformStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Vector3__EXPECTED_HASH, geometry_msgs__msg__Vector3__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__Vector3__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[7].fields = tf2_msgs__action__LookupTransform_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = tf2_msgs__action__LookupTransform_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = tf2_msgs__action__LookupTransform_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[10].fields = tf2_msgs__action__LookupTransform_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&tf2_msgs__msg__TF2Error__EXPECTED_HASH, tf2_msgs__msg__TF2Error__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[11].fields = tf2_msgs__msg__TF2Error__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[12].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_GetResult_Request__FIELD_NAME__goal_id[] = "goal_id";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_GetResult_Request__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_GetResult_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_GetResult_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
      {tf2_msgs__action__LookupTransform_GetResult_Request__FIELDS, 1, 1},
    },
    {tf2_msgs__action__LookupTransform_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_GetResult_Response__FIELD_NAME__status[] = "status";
static char tf2_msgs__action__LookupTransform_GetResult_Response__FIELD_NAME__result[] = "result";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_GetResult_Response__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_GetResult_Response__FIELD_NAME__status, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Response__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Transform__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Vector3__TYPE_NAME, 25, 25},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_GetResult_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
      {tf2_msgs__action__LookupTransform_GetResult_Response__FIELDS, 2, 2},
    },
    {tf2_msgs__action__LookupTransform_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS, 8, 8},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Transform__EXPECTED_HASH, geometry_msgs__msg__Transform__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = geometry_msgs__msg__Transform__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__TransformStamped__EXPECTED_HASH, geometry_msgs__msg__TransformStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = geometry_msgs__msg__TransformStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Vector3__EXPECTED_HASH, geometry_msgs__msg__Vector3__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__Vector3__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[6].fields = tf2_msgs__action__LookupTransform_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&tf2_msgs__msg__TF2Error__EXPECTED_HASH, tf2_msgs__msg__TF2Error__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = tf2_msgs__msg__TF2Error__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__info[] = "info";
static char tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__request[] = "request";
static char tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_GetResult_Event__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Transform__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__TransformStamped__TYPE_NAME, 34, 34},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Vector3__TYPE_NAME, 25, 25},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__msg__TF2Error__TYPE_NAME, 21, 21},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_GetResult_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME, 47, 47},
      {tf2_msgs__action__LookupTransform_GetResult_Event__FIELDS, 3, 3},
    },
    {tf2_msgs__action__LookupTransform_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS, 12, 12},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Transform__EXPECTED_HASH, geometry_msgs__msg__Transform__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = geometry_msgs__msg__Transform__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__TransformStamped__EXPECTED_HASH, geometry_msgs__msg__TransformStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = geometry_msgs__msg__TransformStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Vector3__EXPECTED_HASH, geometry_msgs__msg__Vector3__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__Vector3__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[7].fields = tf2_msgs__action__LookupTransform_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = tf2_msgs__action__LookupTransform_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = tf2_msgs__action__LookupTransform_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&tf2_msgs__msg__TF2Error__EXPECTED_HASH, tf2_msgs__msg__TF2Error__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[10].fields = tf2_msgs__msg__TF2Error__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[11].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char tf2_msgs__action__LookupTransform_FeedbackMessage__FIELD_NAME__goal_id[] = "goal_id";
static char tf2_msgs__action__LookupTransform_FeedbackMessage__FIELD_NAME__feedback[] = "feedback";

static rosidl_runtime_c__type_description__Field tf2_msgs__action__LookupTransform_FeedbackMessage__FIELDS[] = {
  {
    {tf2_msgs__action__LookupTransform_FeedbackMessage__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {tf2_msgs__action__LookupTransform_FeedbackMessage__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription tf2_msgs__action__LookupTransform_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
tf2_msgs__action__LookupTransform_FeedbackMessage__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {tf2_msgs__action__LookupTransform_FeedbackMessage__TYPE_NAME, 47, 47},
      {tf2_msgs__action__LookupTransform_FeedbackMessage__FIELDS, 2, 2},
    },
    {tf2_msgs__action__LookupTransform_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = tf2_msgs__action__LookupTransform_Feedback__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}

static char toplevel_type_raw_source[] =
  "#Simple API\n"
  "string target_frame\n"
  "string source_frame\n"
  "builtin_interfaces/Time source_time\n"
  "builtin_interfaces/Duration timeout\n"
  "\n"
  "#Advanced API\n"
  "builtin_interfaces/Time target_time\n"
  "string fixed_frame\n"
  "\n"
  "#Whether or not to use the advanced API\n"
  "bool advanced\n"
  "\n"
  "---\n"
  "geometry_msgs/TransformStamped transform\n"
  "tf2_msgs/TF2Error error\n"
  "---";

static char action_encoding[] = "action";
static char implicit_encoding[] = "implicit";

// Define all individual source functions

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform__get_individual_type_description_source(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform__TYPE_NAME, 31, 31},
    {action_encoding, 6, 6},
    {toplevel_type_raw_source, 323, 323},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_Goal__TYPE_NAME, 36, 36},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_Result__TYPE_NAME, 38, 38},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_Feedback__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_Feedback__TYPE_NAME, 40, 40},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_SendGoal__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_SendGoal__TYPE_NAME, 40, 40},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_SendGoal_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_SendGoal_Request__TYPE_NAME, 48, 48},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_SendGoal_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_SendGoal_Response__TYPE_NAME, 49, 49},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_SendGoal_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_SendGoal_Event__TYPE_NAME, 46, 46},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_GetResult__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_GetResult__TYPE_NAME, 41, 41},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_GetResult_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_GetResult_Request__TYPE_NAME, 49, 49},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_GetResult_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_GetResult_Response__TYPE_NAME, 50, 50},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_GetResult_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_GetResult_Event__TYPE_NAME, 47, 47},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
tf2_msgs__action__LookupTransform_FeedbackMessage__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {tf2_msgs__action__LookupTransform_FeedbackMessage__TYPE_NAME, 47, 47},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform__get_type_description_sources(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[23];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 23, 23};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[4] = *geometry_msgs__msg__Transform__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__TransformStamped__get_individual_type_description_source(NULL);
    sources[6] = *geometry_msgs__msg__Vector3__get_individual_type_description_source(NULL);
    sources[7] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[8] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[9] = *tf2_msgs__action__LookupTransform_Feedback__get_individual_type_description_source(NULL);
    sources[10] = *tf2_msgs__action__LookupTransform_FeedbackMessage__get_individual_type_description_source(NULL);
    sources[11] = *tf2_msgs__action__LookupTransform_GetResult__get_individual_type_description_source(NULL);
    sources[12] = *tf2_msgs__action__LookupTransform_GetResult_Event__get_individual_type_description_source(NULL);
    sources[13] = *tf2_msgs__action__LookupTransform_GetResult_Request__get_individual_type_description_source(NULL);
    sources[14] = *tf2_msgs__action__LookupTransform_GetResult_Response__get_individual_type_description_source(NULL);
    sources[15] = *tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(NULL);
    sources[16] = *tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(NULL);
    sources[17] = *tf2_msgs__action__LookupTransform_SendGoal__get_individual_type_description_source(NULL);
    sources[18] = *tf2_msgs__action__LookupTransform_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[19] = *tf2_msgs__action__LookupTransform_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[20] = *tf2_msgs__action__LookupTransform_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[21] = *tf2_msgs__msg__TF2Error__get_individual_type_description_source(NULL);
    sources[22] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_Goal__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_Result__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[3] = *geometry_msgs__msg__Transform__get_individual_type_description_source(NULL);
    sources[4] = *geometry_msgs__msg__TransformStamped__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__Vector3__get_individual_type_description_source(NULL);
    sources[6] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[7] = *tf2_msgs__msg__TF2Error__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_Feedback__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_Feedback__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_SendGoal__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[9];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 9, 9};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_SendGoal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[4] = *tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(NULL);
    sources[5] = *tf2_msgs__action__LookupTransform_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[6] = *tf2_msgs__action__LookupTransform_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[7] = *tf2_msgs__action__LookupTransform_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[8] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_SendGoal_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[5];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 5, 5};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_SendGoal_Request__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(NULL);
    sources[4] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_SendGoal_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_SendGoal_Response__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_SendGoal_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_SendGoal_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[4] = *tf2_msgs__action__LookupTransform_Goal__get_individual_type_description_source(NULL);
    sources[5] = *tf2_msgs__action__LookupTransform_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[6] = *tf2_msgs__action__LookupTransform_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_GetResult__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[14];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 14, 14};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_GetResult__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[3] = *geometry_msgs__msg__Transform__get_individual_type_description_source(NULL);
    sources[4] = *geometry_msgs__msg__TransformStamped__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__Vector3__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[8] = *tf2_msgs__action__LookupTransform_GetResult_Event__get_individual_type_description_source(NULL);
    sources[9] = *tf2_msgs__action__LookupTransform_GetResult_Request__get_individual_type_description_source(NULL);
    sources[10] = *tf2_msgs__action__LookupTransform_GetResult_Response__get_individual_type_description_source(NULL);
    sources[11] = *tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(NULL);
    sources[12] = *tf2_msgs__msg__TF2Error__get_individual_type_description_source(NULL);
    sources[13] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_GetResult_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_GetResult_Request__get_individual_type_description_source(NULL),
    sources[1] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_GetResult_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[9];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 9, 9};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_GetResult_Response__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[3] = *geometry_msgs__msg__Transform__get_individual_type_description_source(NULL);
    sources[4] = *geometry_msgs__msg__TransformStamped__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__Vector3__get_individual_type_description_source(NULL);
    sources[6] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[7] = *tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(NULL);
    sources[8] = *tf2_msgs__msg__TF2Error__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_GetResult_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[13];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 13, 13};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_GetResult_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[3] = *geometry_msgs__msg__Transform__get_individual_type_description_source(NULL);
    sources[4] = *geometry_msgs__msg__TransformStamped__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__Vector3__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[8] = *tf2_msgs__action__LookupTransform_GetResult_Request__get_individual_type_description_source(NULL);
    sources[9] = *tf2_msgs__action__LookupTransform_GetResult_Response__get_individual_type_description_source(NULL);
    sources[10] = *tf2_msgs__action__LookupTransform_Result__get_individual_type_description_source(NULL);
    sources[11] = *tf2_msgs__msg__TF2Error__get_individual_type_description_source(NULL);
    sources[12] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
tf2_msgs__action__LookupTransform_FeedbackMessage__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *tf2_msgs__action__LookupTransform_FeedbackMessage__get_individual_type_description_source(NULL),
    sources[1] = *tf2_msgs__action__LookupTransform_Feedback__get_individual_type_description_source(NULL);
    sources[2] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}
