// generated from rosidl_generator_c/resource/idl__type_support.h.em
// with input from tf2_msgs:msg/TFMessage.idl
// generated code does not contain a copyright notice

// IWYU pragma: private, include "tf2_msgs/msg/tf_message.h"


#ifndef TF2_MSGS__MSG__DETAIL__TF_MESSAGE__TYPE_SUPPORT_H_
#define TF2_MSGS__MSG__DETAIL__TF_MESSAGE__TYPE_SUPPORT_H_

#include "rosidl_typesupport_interface/macros.h"

#include "tf2_msgs/msg/rosidl_generator_c__visibility_control.h"

#ifdef __cplusplus
extern "C"
{
#endif

#include "rosidl_runtime_c/message_type_support_struct.h"

// Forward declare the get type support functions for this type.
ROSIDL_GENERATOR_C_PUBLIC_tf2_msgs
const rosidl_message_type_support_t *
ROSIDL_TYPESUPPORT_INTERFACE__MESSAGE_SYMBOL_NAME(
  rosidl_typesupport_c,
  tf2_msgs,
  msg,
  TFMessage
)();

#ifdef __cplusplus
}
#endif

#endif  // TF2_MSGS__MSG__DETAIL__TF_MESSAGE__TYPE_SUPPORT_H_
