// generated from rosidl_adapter/resource/msg.idl.em
// with input from tf2_msgs/msg/TFMessage.msg
// generated code does not contain a copyright notice

#include "geometry_msgs/msg/TransformStamped.idl"

module tf2_msgs {
  module msg {
    struct TFMessage {
      sequence<geometry_msgs::msg::TransformStamped> transforms;
    };
  };
};
