// generated from rosidl_generator_cpp/resource/idl__type_support.hpp.em
// with input from tf2_msgs:msg/TF2Error.idl
// generated code does not contain a copyright notice

#ifndef TF2_MSGS__MSG__DETAIL__TF2_ERROR__TYPE_SUPPORT_HPP_
#define TF2_MSGS__MSG__DETAIL__TF2_ERROR__TYPE_SUPPORT_HPP_

#include "rosidl_typesupport_interface/macros.h"

#include "tf2_msgs/msg/rosidl_generator_cpp__visibility_control.hpp"

#include "rosidl_typesupport_cpp/message_type_support.hpp"

#ifdef __cplusplus
extern "C"
{
#endif
// Forward declare the get type support functions for this type.
ROSIDL_GENERATOR_CPP_PUBLIC_tf2_msgs
const rosidl_message_type_support_t *
  ROSIDL_TYPESUPPORT_INTERFACE__MESSAGE_SYMBOL_NAME(
  rosidl_typesupport_cpp,
  tf2_msgs,
  msg,
  TF2Error
)();
#ifdef __cplusplus
}
#endif

#endif  // TF2_MSGS__MSG__DETAIL__TF2_ERROR__TYPE_SUPPORT_HPP_
